import click
from pydanclick import from_pydantic

from . import weather, hacker_news


@click.group()
def cli():
    """cron for daily things."""
    pass


@cli.command("weather")
@from_pydantic(weather.ForecastConfig)
def forecast(forecast_config: weather.ForecastConfig):
    try:
        for forecast in weather.forecast(forecast_config):
            response = forecast.expect("forecast request failed")
            print(f"{response.day_name}:\n{response.description}")
    except ValueError as e:
        print(f"error: {e}")


@cli.command("hacker-news")
def top():
    stories = hacker_news.recent_top_stories()
    for item in stories:
        print(f"[{item.score:>4}|{item.diff_for_humans():>12}]: {item.title}")
