import requests
from option import Result, Ok, Err
from pydantic import BaseModel, Field
from typing import Annotated, Iterable


class ForecastConfig(BaseModel):
    station_id: Annotated[str, Field(default="WAZ503")]
    periods: Annotated[int, Field(default=1, ge=0)]


class Forecast(BaseModel):
    day_name: str
    description: str


def forecast(config: ForecastConfig) -> Iterable[Result[Forecast, int]]:
    headers = {
        "Accept": "application/geo+json",
        "User-Agent": "(botmatt, contact@publicmatt.com)",
    }
    url = f"https://api.weather.gov/zones/JSON-LD/{config.station_id}/forecast"
    response = requests.get(url, headers=headers)
    match response.status_code:
        case 200:
            data = response.json()
            properties = data.get("properties")
            for period in properties.get("periods"):
                if config.periods <= 0:
                    break
                yield Ok(
                    Forecast(
                        description=period.get("detailedForecast"),
                        day_name=period.get("name"),
                    )
                )
                config.periods -= 1

        case _:
            yield Err(response.status_code)
